==> gnome-power-manager-2.19.5.tar.gz: gnome-power-manager-2.19.5/src/gpm-stock-icons.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2002 Jorn Baayen
 * Copyright (C) 2003,2004 Colin Walters <walters@verbum.org>
 * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GPM_STOCK_ICONS_H
#define __GPM_STOCK_ICONS_H

G_BEGIN_DECLS

#define GPM_STOCK_APP_ICON			"gpm-primary-charged"
#define GPM_STOCK_AC_ADAPTER			"gpm-ac-adapter"
#define GPM_STOCK_BATTERY_CHARGED		"gpm-primary-charged"
#define GPM_STOCK_HIBERNATE			"gpm-hibernate"
#define GPM_STOCK_SUSPEND			"gpm-suspend"
#define GPM_STOCK_STATISTICS			"gpm-statistics"
#define GPM_STOCK_BRIGHTNESS_LCD		"gpm-brightness-lcd"
#define GPM_STOCK_BRIGHTNESS_KBD		"gpm-brightness-kbd"
#define GPM_STOCK_INHIBIT			"gpm-inhibit"

gboolean	gpm_stock_icons_init			(void);
void		gpm_stock_icons_shutdown		(void);

G_END_DECLS

#endif /* __GPM_STOCK_ICONS_H */

==> gnome-power-manager-2.29.2.tar.gz: gnome-power-manager-2.29.2/src/gpm-stock-icons.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2002 Jorn Baayen
 * Copyright (C) 2003,2004 Colin Walters <walters@verbum.org>
 * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __GPM_STOCK_ICONS_H
#define __GPM_STOCK_ICONS_H

G_BEGIN_DECLS

#define GPM_STOCK_APP_ICON			"gnome-power-manager"
#define GPM_STOCK_AC_ADAPTER			"gpm-ac-adapter"
#define GPM_STOCK_BATTERY_CHARGED		"gpm-primary-charged"
#define GPM_STOCK_HIBERNATE			"gpm-hibernate"
#define GPM_STOCK_SUSPEND			"gpm-suspend"
#define GPM_STOCK_STATISTICS			"gnome-power-statistics"
#define GPM_STOCK_BRIGHTNESS_LCD		"gpm-brightness-lcd"
#define GPM_STOCK_BRIGHTNESS_KBD		"gpm-brightness-kbd"
#define GPM_STOCK_INHIBIT			"gpm-inhibit"

G_END_DECLS

#endif /* __GPM_STOCK_ICONS_H */
